@@ -1,16 +1,11 @@
-use std::path::Path;
 use std::io::{stdin, Read};
-use std::str;
+use std::path::Path;
 
-use log;
-use base64;
-use tree_magic_mini;
-use urlencoding::encode as urlencode;
+use clap::{crate_authors, crate_description, crate_version, Clap};
 use color_eyre::eyre::Result;
 use eyre::eyre;
-use clap::{crate_version, crate_authors, crate_description, Clap};
 use flexi_logger::Logger;
-
+use urlencoding::encode as urlencode;
 
 #[derive(Clap)]
 #[clap(version = crate_version!(), author = crate_authors!(), about = crate_description!())]
@@ -19,11 +14,15 @@ struct Opts {
     infile: String,
     #[clap(short, long, about = "Prefer percent encoding for text file.")]
     text: bool,
-    #[clap(short, long, parse(from_occurrences), about = "Verbosity level (repeat to increase).")]
+    #[clap(
+        short,
+        long,
+        parse(from_occurrences),
+        about = "Verbosity level (repeat to increase)."
+    )]
     verbose: i8,
 }
 
-
 fn read_input(infile: &str) -> Result<Vec<u8>> {
     match infile {
         "-" => {
@@ -31,7 +30,7 @@ fn read_input(infile: &str) -> Result<Vec<u8>> {
             let mut stdin = stdin();
             stdin.read_to_end(&mut buf)?;
             Ok(buf)
-        },
+        }
         _ => {
             let path = Path::new(infile);
             std::fs::read(path).map_err(|e| eyre!(e))
@@ -39,24 +38,22 @@ fn read_input(infile: &str) -> Result<Vec<u8>> {
     }
 }
 
-
 fn encode(content: Vec<u8>, mtype: &str, prefer_percent: bool) -> Result<String> {
     let mut body = String::new();
     if prefer_percent && mtype.starts_with("text/") {
-        body = urlencode(str::from_utf8(&content)?)
+        body = urlencode(std::str::from_utf8(&content)?)
     } else {
         base64::encode_config_buf(&content, base64::URL_SAFE, &mut body)
     }
     Ok(body)
 }
 
-
 fn main() -> Result<()> {
     let opts = Opts::parse();
     let level = match opts.verbose {
         0 => "warning",
         1 => "info",
-        _ => "debug"
+        _ => "debug",
     };
     Logger::try_with_str(level)?.start()?;
     color_eyre::install()?;
@@ -67,7 +64,11 @@ fn main() -> Result<()> {
     // Note: "content" is moved to encode() to be dropped early
     let body = encode(content, mtype, opts.text)?;
     log::info!("MIME type: {}", mtype);
-    let encoding = if opts.text && mtype.starts_with("text/") { "" } else { "base64" };
+    let encoding = if opts.text && mtype.starts_with("text/") {
+        ""
+    } else {
+        "base64"
+    };
     print!("data:{};{},{}", mtype, encoding, body);
     Ok(())
 }
